==> ?f=plg_jw_uberPageBreak-v1.0_j1.5.zip: UberPageBreak/includes/elements/template.php <==
<?php 
/*
// JoomlaWorks "UberPageBreak" Plugin for Joomla! 1.5.x - Version 1.0
// Copyright (c) 2006 - 2010 JoomlaWorks, a business unit of Nuevvo Webware Ltd. All rights reserved.
// Released under the GNU/GPL license: http://www.gnu.org/copyleft/gpl.html
// More info at http://www.joomlaworks.gr
// Designed and developed by the JoomlaWorks team
// ***Last update: June 25th, 2010***
*/

// no direct access
defined('_JEXEC') or die('Restricted access');

class JElementTemplate extends JElement {

	var $_name = 'template';

	function fetchElement($name, $value, & $node, $control_name) {
		
		jimport('joomla.filesystem.folder');
		$plgTemplatesPath = JPATH_SITE.DS.'plugins'.DS.'content'.DS.'UberPageBreak'.DS.'tmpl';
		$plgTemplatesFolders = JFolder::folders($plgTemplatesPath);
		
		$db =& JFactory::getDBO();
		$query = "SELECT template FROM #__templates_menu WHERE client_id = 0 AND menuid = 0";
		$db->setQuery($query);
		$defaultemplate = $db->loadResult();
		$templatePath = JPATH_SITE.DS.'templates'.DS.$defaultemplate.DS.'html'.DS.'UberPageBreak';
		
		if (JFolder::exists($templatePath)){
			$templateFolders = JFolder::folders($templatePath);
			$folders = @array_merge($templateFolders, $plgTemplatesFolders);
			$folders = @array_unique($folders);
		} else {
			$folders = $plgTemplatesFolders;
		}
		
		sort($folders);
		
		$options = array();
		foreach($folders as $folder) {
			$options[] = JHTML::_('select.option', $folder, $folder);
		}
		
		array_unshift($options, JHTML::_('select.option','','-- '.JText::_('Select template').' --'));
		
		return JHTML::_('select.genericlist', $options, ''.$control_name.'['.$name.']', 'class="inputbox"', 'value', 'text', $value, $control_name.$name);
	
	}

}

==> ?f=plg_jw_uberPageBreak-v1.1_j1.5.zip: UberPageBreak/includes/elements/template.php <==
<?php 
/**
 * @version		1.1
 * @package		UberPageBreak (plugin)
 * @author    JoomlaWorks - http://www.joomlaworks.gr
 * @copyright	Copyright (c) 2006 - 2011 JoomlaWorks, a business unit of Nuevvo Webware Ltd. All rights reserved.
 * @license		GNU/GPL license: http://www.gnu.org/copyleft/gpl.html
 */

// no direct access
defined('_JEXEC') or die('Restricted access');

class JElementTemplate extends JElement {

	var $_name = 'template';

	function fetchElement($name, $value, & $node, $control_name) {
		
		jimport('joomla.filesystem.folder');
		$plgTemplatesPath = JPATH_SITE.DS.'plugins'.DS.'content'.DS.'UberPageBreak'.DS.'tmpl';
		$plgTemplatesFolders = JFolder::folders($plgTemplatesPath);
		
		$db =& JFactory::getDBO();
		$query = "SELECT template FROM #__templates_menu WHERE client_id = 0 AND menuid = 0";
		$db->setQuery($query);
		$defaultemplate = $db->loadResult();
		$templatePath = JPATH_SITE.DS.'templates'.DS.$defaultemplate.DS.'html'.DS.'UberPageBreak';
		
		if (JFolder::exists($templatePath)){
			$templateFolders = JFolder::folders($templatePath);
			$folders = @array_merge($templateFolders, $plgTemplatesFolders);
			$folders = @array_unique($folders);
		} else {
			$folders = $plgTemplatesFolders;
		}
		
		sort($folders);
		
		$options = array();
		foreach($folders as $folder) {
			$options[] = JHTML::_('select.option', $folder, $folder);
		}
		
		array_unshift($options, JHTML::_('select.option','','-- '.JText::_('Select template').' --'));
		
		return JHTML::_('select.genericlist', $options, ''.$control_name.'['.$name.']', 'class="inputbox"', 'value', 'text', $value, $control_name.$name);
	
	}

}
